searchData={"items":[{"type":"module","title":"Pdf","doc":"The missing PDF library for Elixir.","ref":"Pdf.html"},{"type":"module","title":"Usage - Pdf","doc":"```elixir\nPdf.build([size: :a4, compress: true], fn pdf ->\n  pdf\n  |> Pdf.set_info(title: \"Demo PDF\")\n  |> Pdf.set_font(\"Helvetica\", 10)\n  |> Pdf.text_at({200,200}, \"Welcome to Pdf\")\n  |> Pdf.write_to(\"test.pdf\")\nend)\n```","ref":"Pdf.html#module-usage"},{"type":"module","title":"Page sizes - Pdf","doc":"The available page sizes are:\n\n - `:a0` - `:a9`\n - `:b0` - `:b9`\n - `:c5e`\n - `:comm10e`\n - `:dle`\n - `:executive`\n - `:folio`\n - `:ledger`\n - `:legal`\n - `:letter`\n - `:tabloid`\n - a custom size `[width, height]` in Pdf points.\n\nor you can also specify a tuple `{size, :landscape}`.","ref":"Pdf.html#module-page-sizes"},{"type":"function","title":"Pdf.add_font/2","doc":"Add a font to the list of available fonts.\n\nCurrently only _Type 1_ AFM/PFB fonts are supported.\n\n```elixir\n\nfonts_dir = Application.app_dir(:my_app) |> Path.join(\"priv\", \"fonts\")\n\npdf\n|> Pdf.add_font(Path.join(fonts_dir, \"DejavuSans.afm\")\n|> Pdf.add_font(Path.join(fonts_dir, \"DejavuSans-Bold.afm\")\n```\n\nThe font can then be set with `set_font/3`.\n\nYou have to `add_font/2` all variants you want to use, bold, italic, ...","ref":"Pdf.html#add_font/2"},{"type":"function","title":"Pdf.add_image/3","doc":"Add an images (PNG, or JPEG only) at the given coordinates.","ref":"Pdf.html#add_image/3"},{"type":"function","title":"Pdf.add_image/4","doc":"Add an images (PNG, or JPEG only) at the given coordinates.\n\nYou can specify a `:width` and `:height` in the options, the image will then be scaled.","ref":"Pdf.html#add_image/4"},{"type":"function","title":"Pdf.add_page/2","doc":"Add a new page to the Pdf with the given page size.","ref":"Pdf.html#add_page/2"},{"type":"function","title":"Pdf.autoprint/1","doc":"Adds an autoprint action to the Pdf.\n\nThis is can be useful for generating a PDF that will automatically open the print dialog in a browser","ref":"Pdf.html#autoprint/1"},{"type":"function","title":"Pdf.build/2","doc":"Builds a PDF document taking care of cleaning up resources on completion.\n\n```elixir\nPdf.build([size: :a3], fn pdf ->\n  pdf\n  |> Pdf.set_font(\"Helvetica\", 12)\n  |> Pdf.text_at({100, 100}, \"Open\")\n  |> Pdf.write_to(\"test.pdf\")\nend)\n```\nis equivalent to\n```elixir\n{:ok, pdf} = Pdf.new(size: :a3)\npdf\n|> Pdf.set_font(\"Helvetica\", 12)\n|> Pdf.text_at({100, 100}, \"Open\")\n|> Pdf.write_to(\"test.pdf\")\n|> Pdf.cleanup()\n```","ref":"Pdf.html#build/2"},{"type":"function","title":"Pdf.cleanup/1","doc":"Stop the Pdf process releasing all document memory.","ref":"Pdf.html#cleanup/1"},{"type":"function","title":"Pdf.cm/1","doc":"Convert the given value from cm to Pdf points","ref":"Pdf.html#cm/1"},{"type":"function","title":"Pdf.cursor/1","doc":"Gets the current cursor position, that is the vertical position.","ref":"Pdf.html#cursor/1"},{"type":"function","title":"Pdf.delete/1","doc":"","ref":"Pdf.html#delete/1"},{"type":"function","title":"Pdf.export/1","doc":"Export the Pdf to a binary representation.\n\nThis is can be used in eg Phoenix to send a PDF to the browser.\n\n```elixir\n  report =\n    pdf\n    |> ...\n    |> Pdf.export()\n\n conn\n  |> put_resp_content_type(\"application/pdf\")\n  |> put_resp_header(\n    \"content-disposition\",\n    \"attachment; filename=\\\"document.pdf\\\"\"\n  )\n  |> send_resp(200, report)\n```","ref":"Pdf.html#export/1"},{"type":"function","title":"Pdf.fill/1","doc":"Fill the current drawing with the previously set color.","ref":"Pdf.html#fill/1"},{"type":"function","title":"Pdf.inches/1","doc":"Convert the given value from inches to Pdf points","ref":"Pdf.html#inches/1"},{"type":"function","title":"Pdf.line/3","doc":"Draw a line between 2 points.","ref":"Pdf.html#line/3"},{"type":"function","title":"Pdf.line_append/2","doc":"Draw a line from the last position to the given coordinates.\n```elixir\n  pdf\n  |> Pdf.move_to({100, 100})\n  |> Pdf.line_append({200, 200})\n```","ref":"Pdf.html#line_append/2"},{"type":"function","title":"Pdf.mm/1","doc":"Convert the given value from mm to Pdf points","ref":"Pdf.html#mm/1"},{"type":"function","title":"Pdf.move_down/2","doc":"Move the cursor `amount` points down.","ref":"Pdf.html#move_down/2"},{"type":"function","title":"Pdf.move_to/2","doc":"Move the cursor to the given coordinates.","ref":"Pdf.html#move_to/2"},{"type":"function","title":"Pdf.new/1","doc":"Create a new Pdf process\n\nThe following options can be given:\n\n:size      |  Page size, defaults to `:a4`\n:compress  |  Compress the Pdf, default: `true`\n\nThere is no standard font selected when creating a new PDF, so set one with `set_font/3` before adding text.","ref":"Pdf.html#new/1"},{"type":"function","title":"Pdf.open/2","doc":"","ref":"Pdf.html#open/2"},{"type":"function","title":"Pdf.page_number/1","doc":"Returns the current page number.","ref":"Pdf.html#page_number/1"},{"type":"function","title":"Pdf.picas/1","doc":"Convert the given value from picas to Pdf points","ref":"Pdf.html#picas/1"},{"type":"function","title":"Pdf.pixels_to_points/2","doc":"Convert the given value from pixels to Pdf points","ref":"Pdf.html#pixels_to_points/2"},{"type":"function","title":"Pdf.points/1","doc":"The unit of measurement in a Pdf are points, where *1 point = 1/72 inch*.\nThis means that a standard A4 page, 8.27 inch, translates to 595 points.","ref":"Pdf.html#points/1"},{"type":"function","title":"Pdf.rectangle/3","doc":"Draw a rectangle from coordinates x,y (lower left corner) for a given width and height.","ref":"Pdf.html#rectangle/3"},{"type":"function","title":"Pdf.set_author/2","doc":"Sets the author in the PDF information section.","ref":"Pdf.html#set_author/2"},{"type":"function","title":"Pdf.set_creator/2","doc":"Sets the creator in the PDF information section.","ref":"Pdf.html#set_creator/2"},{"type":"function","title":"Pdf.set_cursor/2","doc":"Set the cursor position.","ref":"Pdf.html#set_cursor/2"},{"type":"function","title":"Pdf.set_fill_color/2","doc":"Set the color to use when filling.\n\nThis takes either a `Pdf.Color.color/1` atom, an RGB tuple or a CMYK tuple.","ref":"Pdf.html#set_fill_color/2"},{"type":"function","title":"Pdf.set_font/3","doc":"Sets the font that will be used for all text from here on.\nYou can either specify the font size, or a list of options:\n\nOption  |  Value  | Default\n:------ | :------ | :------\n`:size`   | integer | 10\n`:bold`   | boolean | false\n`:italic` | boolean | false","ref":"Pdf.html#set_font/3"},{"type":"function","title":"Pdf.set_font_size/2","doc":"Sets the font size.\n\nThe font has to have been previously set!","ref":"Pdf.html#set_font_size/2"},{"type":"function","title":"Pdf.set_info/2","doc":"Set multiple keys in the PDF information section.\n\nValid keys\n  - `:author`\n  - `:created`\n  - `:creator`\n  - `:keywords`\n  - `:modified`\n  - `:producer`\n  - `:subject`\n  - `:title`","ref":"Pdf.html#set_info/2"},{"type":"function","title":"Pdf.set_keywords/2","doc":"Sets the keywords in the PDF information section.","ref":"Pdf.html#set_keywords/2"},{"type":"function","title":"Pdf.set_line_cap/2","doc":"The line endings to draw, see `t:cap_style/0`.","ref":"Pdf.html#set_line_cap/2"},{"type":"function","title":"Pdf.set_line_join/2","doc":"The join style to use where lines meet, see `t:join_style/0`.","ref":"Pdf.html#set_line_join/2"},{"type":"function","title":"Pdf.set_line_width/2","doc":"The width to use when drawing lines.","ref":"Pdf.html#set_line_width/2"},{"type":"function","title":"Pdf.set_producer/2","doc":"Sets the producer in the PDF information section.","ref":"Pdf.html#set_producer/2"},{"type":"function","title":"Pdf.set_stroke_color/2","doc":"Set the color to use when drawing lines.\n\nThis takes either a `Pdf.Color.color/1` atom, an RGB tuple or a CMYK tuple.","ref":"Pdf.html#set_stroke_color/2"},{"type":"function","title":"Pdf.set_subject/2","doc":"Sets the subject in the PDF information section.","ref":"Pdf.html#set_subject/2"},{"type":"function","title":"Pdf.set_text_leading/2","doc":"Leading is a typography term that describes the distance between each line of text. The name comes from a time when typesetting was done by hand and pieces of lead were used to separate the lines.\n\nToday, leading is often used synonymously with \"line height\" or \"line spacing.\"","ref":"Pdf.html#set_text_leading/2"},{"type":"function","title":"Pdf.set_title/2","doc":"Sets the title in the PDF information section.","ref":"Pdf.html#set_title/2"},{"type":"function","title":"Pdf.size/1","doc":"Returns a `{width, height}` for the current page.","ref":"Pdf.html#size/1"},{"type":"function","title":"Pdf.stroke/1","doc":"Perform all the previous graphic commands.","ref":"Pdf.html#stroke/1"},{"type":"function","title":"Pdf.table/5","doc":"Add a table in the document at the given coordinates.\n\nSee [Tables](tables.html) for more information on how to use tables.","ref":"Pdf.html#table/5"},{"type":"function","title":"Pdf.table!/5","doc":"Add a table in the document at the given coordinates.\nRaises an exception if the table does not fit the dimensions.\n\nSee [Tables](tables.html) for more information on how to use tables.","ref":"Pdf.html#table!/5"},{"type":"function","title":"Pdf.text_at/3","doc":"Writes the text at the given coordinates.\nThe coordinates are the bottom left of the text.\n\nThe _text_ can be either a binary or a list of binaries or annotated binaries.\nAll text will be drawn on the same line, no wrapping will occur, it may overrun the page.\n\nWhen given a list, you can supply a mix of binaries and annotated binaries.\nAn annotated binary is a tuple `{binary, options}`, with the options being:\n\nOption  |  Value  | Default\n:------ | :------ | :------\n`:font_size`   | integer | current\n`:bold`   | boolean | false\n`:italic` | boolean | false\n`:leading` | integer | current\n`:color` | :atom | current\n\nWhen setting `bold: true` or `italic: true`, make sure that your current font supports these or an error will occur.\nIf using an external font, you have to `add_font/2` all variants you want to use.","ref":"Pdf.html#text_at/3"},{"type":"function","title":"Pdf.text_at/4","doc":"Writes the text at the given coordinates.\nThe coordinates are the bottom left of the text.\n\nThe _text_ can be either a binary or a list of binaries or annotated binaries, see `text_at/3`.\nAll text will be drawn on the same line, no wrapping will occur, it may overrun the page.\n\nThe `:kerning` option if set to `true` will apply to all rendered text.\nKerning refers to the spacing between the characters of a font. Without kerning, each character takes up a block of space and the next character is printed after it. When kerning is applied to a font, the characters can vertically overlap. This does not mean that the characters actually touch, but instead it allows part of two characters to take up the same vertical space. Kerning is available in some fonts.","ref":"Pdf.html#text_at/4"},{"type":"function","title":"Pdf.text_lines/4","doc":"This function draws a number of text lines starting at the given coordinates.\nThe list can overrun the page, no errors or wrapping will occur.\n\nKerning can be set, see `text_at/4` for more information.","ref":"Pdf.html#text_lines/4"},{"type":"function","title":"Pdf.text_wrap/4","doc":"Writes the text wrapped within the confines of the given dimensions.\nThe `{x,y}` is the top-left of corner of the box, for this reason it is not wise to try to match it up with `text_at` on the same line.\n\nThe y-coordinate can also be set to `:cursor`.\n\nThe text will break at whitespace, such as, space, soft-hyphen, hyphen, cr, lf,  tab, ...\n\nIf the text is too large for the box, it may overrun its boundaries, but only horizontally.\n\nThis function will return a tuple `{pid, :complete}` if all text was rendered, or `{pid, remaining}` if not.\nIt can subsequently be called with the _remaining_ data, after eg starting a new page, until `{pid, :complete}`.\n\nThe _text_ can be either a binary or a list of binaries or annotated binaries.\nThe `:kerning` option if set will apply to all rendered text.\n\nWhen given a list, you can supply a mix of binaries and annotated binaries.\nAn annotated binary is a tuple `{binary, options}`, with the options being:\n\nOption  |  Value  | Default\n:------ | :------ | :------\n`:font_size`   | integer | current\n`:bold`   | boolean | false\n`:italic` | boolean | false\n`:leading` | integer | current\n`:color` | :atom | current\n\nWhen choosing `:bold` or `:italic`, make sure that your current font supports these or an error will occur.\nIf using an external font, you have to `add_font/2` all variants you want to use.","ref":"Pdf.html#text_wrap/4"},{"type":"function","title":"Pdf.text_wrap/5","doc":"This function has the same options as `text_wrap/4`, but also supports additional options that will be applied to the complete text.\n\nOption  |  Value  | Default\n:------ | :------ | :------\n`:align` | :left , :center , :right | :left\n`:kerning` | `boolean` | false","ref":"Pdf.html#text_wrap/5"},{"type":"function","title":"Pdf.text_wrap!/4","doc":"This function has the same options as `text_wrap/4`, but if the text is too large for the box, a `RuntimeError` will be raised.","ref":"Pdf.html#text_wrap!/4"},{"type":"function","title":"Pdf.text_wrap!/5","doc":"This function has the same options as `text_wrap/5`, but if the text is too large for the box, a `RuntimeError` will be raised.","ref":"Pdf.html#text_wrap!/5"},{"type":"function","title":"Pdf.write_to/2","doc":"Write the PDF to the given path","ref":"Pdf.html#write_to/2"},{"type":"type","title":"Pdf.cap_style/0","doc":"A code specifying the shape of the endpoints for an open path that is stroked.\n\n- :butt (default)\n\n  The stroke shall be squared of at the endpoint of the path.\n\n- :round\n\n  A small semicircular arc with a diameter equal to the line width shall be drawn around the endpoint and shall be filled in.\n\n- :square | :projecting_square\n\n  The stroke shall continue beyond the endpoint of the path for a distance equal to half the line width and shall be squared of.","ref":"Pdf.html#t:cap_style/0"},{"type":"type","title":"Pdf.cmyk/0","doc":"Specify a color by it's CMYK make-up.","ref":"Pdf.html#t:cmyk/0"},{"type":"type","title":"Pdf.color_name/0","doc":"Use one of the colors in the `Pdf.Color` module.","ref":"Pdf.html#t:color_name/0"},{"type":"type","title":"Pdf.coords/0","doc":"Most functions take a coordinates tuple, `{x, y}`.\nIn Pdf these start from the bottom-left of the page.","ref":"Pdf.html#t:coords/0"},{"type":"type","title":"Pdf.dimension/0","doc":"Width and height expressed in Pdf points","ref":"Pdf.html#t:dimension/0"},{"type":"type","title":"Pdf.height/0","doc":"The height in points","ref":"Pdf.html#t:height/0"},{"type":"type","title":"Pdf.join_style/0","doc":"The line join style shall specify the shape to be used at the corners of paths that are stroked.\n\n- :miter\n\n  The outer edges of the strokes for the two segments shall be extended until they meet at an angle. If the segments meet at too sharp an angle (as defined in section 8.4.3.5 of the PDF specs), a bevel join shall be used instead.\n\n- :round\n\n  An arc of a circle with a diameter equal to the line width shall be drawn around the point where the two segments meet, connecting the outer edges of the strokes for the two segments.  This pieslice-shae figure shall be filled in, producing a rounded corner.\n\n- :bevel\n\n  The two segments shall be finished with butt caps (see `t:cap_style/0`) and the resulting notch beyond the ends of the segments shall be filled with a triangle.","ref":"Pdf.html#t:join_style/0"},{"type":"type","title":"Pdf.rgb/0","doc":"Specify a color by it's RGB make-up.","ref":"Pdf.html#t:rgb/0"},{"type":"type","title":"Pdf.width/0","doc":"The width in points","ref":"Pdf.html#t:width/0"},{"type":"type","title":"Pdf.x/0","doc":"The x-coordinate","ref":"Pdf.html#t:x/0"},{"type":"type","title":"Pdf.y/0","doc":"The y-coordinate","ref":"Pdf.html#t:y/0"},{"type":"module","title":"Pdf.Color","doc":"A list of predefined colors you can use","ref":"Pdf.Color.html"},{"type":"function","title":"Pdf.Color.color/1","doc":"This functions returns the `rgb` tuple for the given color.\n\n :pink \n :light_pink \n :hot_pink \n :deep_pink \n :pale_violet_red \n :medium_violet_red \n :light_salmon \n :salmon \n :dark_salmon \n :light_coral \n :indian_red \n :crimson \n :firebrick \n :dark_red \n :red \n :orange_red \n :tomato \n :coral \n :dark_orange \n :orange \n :yellow \n :light_yellow \n :lemon_chiffon \n :light_goldenrod_yellow \n :papaya_whip \n :moccasin \n :peach_puff \n :pale_goldenrod \n :khaki \n :dark_khaki \n :gold \n :cornsilk \n :blanched_almond \n :bisque \n :navajo_white \n :wheat \n :burlywood \n :tan \n :rosy_brown \n :sandy_brown \n :goldenrod \n :dark_goldenrod \n :peru \n :chocolate \n :saddle_brown \n :sienna \n :brown \n :maroon \n :dark_olive_green \n :olive \n :olive_drab \n :yellow_green \n :lime_green \n :lime \n :lawn_green \n :chartreuse \n :green_yellow \n :spring_green \n :medium_spring_green \n :light_green \n :pale_green \n :dark_sea_green \n :medium_aquamarine \n :medium_sea_green \n :sea_green \n :forest_green \n :green \n :dark_green \n :aqua \n :cyan \n :light_cyan \n :pale_turquoise \n :aquamarine \n :turquoise \n :medium_turquoise \n :dark_turquoise \n :light_sea_green \n :cadet_blue \n :dark_cyan \n :teal \n :light_steel_blue \n :powder_blue \n :light_blue \n :sky_blue \n :light_sky_blue \n :deep_sky_blue \n :dodger_blue \n :cornflower_blue \n :steel_blue \n :royal_blue \n :blue \n :medium_blue \n :dark_blue \n :navy \n :midnight_blue \n :lavender \n :thistle \n :plum \n :violet \n :orchid \n :fuchsia \n :magenta \n :medium_orchid \n :medium_purple \n :blue_violet \n :dark_violet \n :dark_orchid \n :dark_magenta \n :purple \n :indigo \n :dark_slate_blue \n :slate_blue \n :medium_slate_blue \n :white \n :snow \n :honeydew \n :mint_cream \n :azure \n :alice_blue \n :ghost_white \n :white_smoke \n :seashell \n :beige \n :old_lace \n :floral_white \n :ivory \n :antique_white \n :linen \n :lavender_blush \n :misty_rose \n :gainsboro \n :light_gray \n :silver \n :dark_gray \n :gray \n :dim_gray \n :light_slate_gray \n :slate_gray \n :dark_slate_gray \n :black","ref":"Pdf.Color.html#color/1"},{"type":"module","title":"Pdf.Fonts.Server","doc":"","ref":"Pdf.Fonts.Server.html"},{"type":"function","title":"Pdf.Fonts.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Pdf.Fonts.Server.html#child_spec/1"},{"type":"module","title":"Pdf.ObjectCollection.Server","doc":"","ref":"Pdf.ObjectCollection.Server.html"},{"type":"function","title":"Pdf.ObjectCollection.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Pdf.ObjectCollection.Server.html#child_spec/1"},{"type":"module","title":"Pdf.Server","doc":"","ref":"Pdf.Server.html"},{"type":"function","title":"Pdf.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Pdf.Server.html#child_spec/1"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"0.7.1 (2024-07-23) - Changelog","doc":"- Fix memory leak when cleaning up a PDF process","ref":"changelog.html#0-7-1-2024-07-23"},{"type":"extras","title":"0.7.0 (2024-07-12) - Changelog","doc":"- Add `autoprint/1` to automatically open the print dialog in a browser","ref":"changelog.html#0-7-0-2024-07-12"},{"type":"extras","title":"0.6.1 (2023-01-19) - Changelog","doc":"- Fix bug with zero width strings and empty rows (also fixes [#24])\n- Fix issue with nil cap height [#35]\n- Raise RuntimeError when attempting to add text without a font [#36]\n- Fix typespec for `text_wrap/5` [#37]","ref":"changelog.html#0-6-1-2023-01-19"},{"type":"extras","title":"0.6.0 (2021-12-07) - Changelog","doc":"- Add `:odd` and `:even` to `:row_style` on table with a lower precedence than indexed styles\n- Fix bug where only the first non-WinAnsi character was replaced [#32]","ref":"changelog.html#0-6-0-2021-12-07"},{"type":"extras","title":"0.5.0 (2020-12-02) - Changelog","doc":"- Catch errors raised within the GenServer and re-raise them in the calling process","ref":"changelog.html#0-5-0-2020-12-02"},{"type":"extras","title":"0.4.0 (2020-08-12) - Changelog","doc":"- Add `:encoding_replacement_character` option to supply a replacement character when encoding fails\n- Add `:allow_row_overflow` option to `Pdf.table/4` to allow row contents to be split across pages","ref":"changelog.html#0-4-0-2020-08-12"},{"type":"extras","title":"0.3.7 (2020-04-29) - Changelog","doc":"- Bug fix: Fix memory leak by stopping internal processes","ref":"changelog.html#0-3-7-2020-04-29"},{"type":"extras","title":"0.3.6 (2020-04-22) - Changelog","doc":"- Bug fix: Correctly handle encoded text as binary, not UTF-8 encoded string\n- Bug fix: External fonts now work like built-in fonts #17\n- Bug fix: Reset colours changed by attributed text\n- Bug fix: Fix global options for text_at/4 when using a string #11","ref":"changelog.html#0-3-6-2020-04-22"},{"type":"extras","title":"0.3.5 (2020-04-14) - Changelog","doc":"- Deprecate: `Pdf.delete/1` in favour of `Pdf.cleanup/1`\n- Deprecate: `Pdf.open/2` in favour of `Pdf.build/2`","ref":"changelog.html#0-3-5-2020-04-14"},{"type":"extras","title":"License","doc":"# The MIT License (MIT)\n\nCopyright (c) 2016 Andrew Timberlake\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of\nthis software and associated documentation files (the “Software”), to deal in\nthe Software without restriction, including without limitation the rights to\nuse, copy, modify, merge, publish, distribute, sublicense, and/or sell copies\nof the Software, and to permit persons to whom the Software is furnished to do\nso, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# Pdf\n\n[![Build Status](https://travis-ci.org/andrewtimberlake/elixir-pdf.svg?branch=master)](https://travis-ci.org/andrewtimberlake/elixir-pdf)\n[![Module Version](https://img.shields.io/hexpm/v/pdf.svg)](https://hex.pm/packages/pdf)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/pdf/)\n[![Total Download](https://img.shields.io/hexpm/dt/pdf.svg)](https://hex.pm/packages/pdf)\n[![License](https://img.shields.io/hexpm/l/pdf.svg)](https://github.com/andrewtimberlake/elixir-pdf/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/andrewtimberlake/elixir-pdf.svg)](https://github.com/andrewtimberlake/elixir-pdf/commits/master)\n\nThe missing PDF library for Elixir.","ref":"readme.html"},{"type":"extras","title":"Usage - Overview","doc":"```elixir\nPdf.build([size: :a4, compress: true], fn pdf ->\n  pdf\n  |> Pdf.set_info(title: \"Demo PDF\")\n  |> Pdf.set_font(\"Helvetica\", 10)\n  |> Pdf.text_at({200,200}, \"Welcome to Pdf\")\n  |> Pdf.write_to(\"test.pdf\")\nend)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Overview","doc":"Add `:pdf` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pdf, \"~> 0.6\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2016 Andrew Timberlake\n\nThis work is free. You can redistribute it and/or modify it under the\nterms of the MIT License. See the [LICENSE.md](./LICENSE.md) file for more details.","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"Tables","doc":"# Tables\n\nUse `Pdf.table/5` to add a table to your PDF.\nThis guide explains the different options you can use with the following example, you can see the generated [pdf](assets/table.pdf).\n\n```elixir\ndata = [\n  [\"Header 1\", \"Header 2\", \"Header 3\", \"Header 4\"],\n  [\"Col 1,1\", \"Col 1,2\", \"Col 1,3\", \"Col 1,4\"],\n  [\"Col 2,1\", \"Column 2,2\", \"Col 2,3\", \"Col 2,4\"],\n  [nil, \"mmmmmmmmmm\", nil, \"mmmmmmmmmmm\"],\n  [\"Col 3,1\", [\"Column \", {\"3,2\", bold: true}], \"Col 3,3\", \"Col 3,4\"],\n  [\"Col 4,1\", \"Column 4,2\", \"Col 4,3\", \"Col 4,4\"],\n  [nil, nil, \"Col 5,3\", \"Col 5,4\"]\n]\n\n{:ok, pdf} = Pdf.new(size: :a4)\n\ntable_opts = [\n  padding: 2,\n  background: :gainsboro,\n  repeat_header: 1,\n  cols: [\n    [width: 100, font_size: 8],\n    [],\n    [min_width: 30, background: :dark_gray, color: :white],\n    [width: 80, align: :right, padding: {2, 4}]\n  ],\n  rows: %{\n    0 => [\n      bold: true,\n    align: :center,\n    kerning: true,\n    cols: [\n      [colspan: 2]\n    ]\n    ],\n    2 => [background: :silver, cols: [[], [], [background: :dark_green]]],\n    -1 => [\n      bold: true,\n    border: {0.5, 0, 0, 0},\n    cols: [\n      [background: nil],\n      [background: nil],\n      [border: {0, 0.5, 0.5, 0.5}],\n      [border: {0, 0.5, 0.5, 0.5}, color: :red]\n    ]\n    ]\n  },\nborder: 0.5\n]\n\npdf\n  |> Pdf.set_font(\"Helvetica\", 12)\n  |> Pdf.set_fill_color(:black)\n  |> Pdf.set_line_cap(:square)\n  |> Pdf.set_line_join(:miter)\n\n{pdf, remaining} =\n  pdf\n  |> Pdf.table({100, 800}, {400, 80}, data, table_opts)\n\ncursor = Pdf.cursor(pdf)\n\n{pdf, :complete} =\n  pdf\n  |> Pdf.table({100, cursor - 20}, {400, 200}, remaining, table_opts)\n\npdf\n  |> Pdf.cleanup()\n```\n\nYou can use either `Pdf.table/5` or `Pdf.table!/5` to add a table to your Pdf.\n\n`Pdf.table/5` returns a tuple :\n\n- `{pid, :complete}` All data was processed.\n- `{pid, remaining}` Not all data fit into the given dimensions.\n\n  This allows you to draw the remaining data on eg another page.\n\n`Pdf.table!/5` will raise a `RuntimeError` if the data does not fit.","ref":"tables.html"},{"type":"extras","title":"Options - Tables","doc":"","ref":"tables.html#options"},{"type":"extras","title":"General options - Tables","doc":"These options can be applied to the table, rows and columns.\n\nOptions | Explanation\n:-----  | :------\n`:background` | One of the predefined color atomsi (see `Pdf.Color.color/1`), an RGB tuple or a CMYK tuple.\n`:border` | The thickness of the border, see `:padding` below.\n`:color` | The font color, accepts the same options as `:background`.\n`:font_size` | Font size\n`:bold` | `true` or `false`\n`:italic` | `true` or `false`\n`:padding` | The padding to apply, cfr CSS, can take for all sides `{int}`, `{horizontal, vertical}`, `{top, horizontal, bottom}`, `{top, right, bottom, left}`\n`:colspan` | The number of columns to merge together","ref":"tables.html#general-options"},{"type":"extras","title":"Table specific options - Tables","doc":"Extra Options | Explanation\n:------------ | :------\n`:cols` | Definitions for the individual columns.\n`:repeat_header` | The number of rows that make up the header of the table, and that will be repeated when the data overflows the supplied boundary.\n`:rows` | Definitions for the individual rows.\n`:encoding_replacement_character` | Supply a character to replace characters that don't match the WIN ANSI encoding\n`:allow_row_overflow` | (boolean) If a row can be split when returning {:continue, data}. Needed for when a row content will be longer than a full table height\n\nThe headers if set will be repeated with each call.","ref":"tables.html#table-specific-options"},{"type":"extras","title":"Column specific options - Tables","doc":"`:cols` takes a list of column definitions.\n\nExtra Options | Explanation\n:----- | :-----\n`:width` | Fixed width\n`:max_width` | The maximum column width\n`:min_width` | The minimum column width","ref":"tables.html#column-specific-options"},{"type":"extras","title":"Row specific options - Tables","doc":"`:rows` takes a map of row definitions.\nA row definition is a list of attributes, eg. `[background: :silver]` to apply to the given row(s).\n\n- ` ` Definition for row with this number. Valid row numbers are `-number..0..number of rows in data`, eg 0 for the first row, -1 for the last, -2 for the second last, etc. These will take precedence over `:odd` and `:even`.\n- `:even` Definition for rows with even numbers, 0,2,4, ...\n- `:odd`  Definition for rows with odd numbers, 1,3,5, ...\n\nExtra Options | Explanation\n:----- | :-----\n`:cols` | Definitions for the columns in this single row","ref":"tables.html#row-specific-options"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]},"content_type":"text/markdown"}